@@ -88,14 +88,74 @@ class Node(ABC):
         tag = None
         if tag_name in self.tags.keys():
             tag = self.tags[tag_name]
-        elif hasattr(self, "nodes"):
-            for node in self.nodes.values():
-                tag = node.get_tag(tag_name)
-                if tag:
-                    break
+        else:
+            if hasattr(self, "connections"):
+                for connection in self.connections.values():
+                    if tag_name in connection.tags.keys():
+                        tag = connection.tags[tag_name]
+
+            if hasattr(self, "nodes") and tag is None:
+                for node in self.nodes.values():
+                    tag = node.get_tag(tag_name)
+                    if tag:
+                        break
 
         return tag
 
+    def get_all_connections(self, recurse=False):
+        """Gets all Connection objects associated with this Node
+
+        Parameters
+        ----------
+        recurse : bool
+            Whether or not to get connections recursively.
+            Default is False, meaning that only direct children will be returned.
+
+        Returns
+        ------
+        list of Connection
+            Connection objects inside this Node.
+            If `recurse` is True, all children, grandchildren, etc. are returned.
+            If False, only direct children are returned.
+        """
+        connections = []
+        if hasattr(self, "connections"):
+            connections = list(self.connections.values())
+
+        if recurse:
+            if hasattr(self, "nodes"):
+                for node in self.nodes.values():
+                    connections = connections + node.get_all_connections(
+                        recurse=recurse
+                    )
+
+        return connections
+
+    def get_all_nodes(self, recurse=False):
+        """Gets all Node objects associated with this Node
+
+        Parameters
+        ----------
+        recurse : bool
+            Whether or not to get nodes recursively.
+            Default is False, meaning that only direct children will be returned.
+
+        Returns
+        ------
+        list of Node
+            Node objects inside this Node.
+            If `recurse` is True, all children, grandchildren, etc. are returned.
+            If False, only direct children are returned.
+        """
+        nodes = []
+        if hasattr(self, "nodes"):
+            nodes = list(self.nodes.values())
+            if recurse:
+                for node in self.nodes.values():
+                    nodes = nodes + node.get_all_nodes(recurse=recurse)
+
+        return nodes
+
 
 class Network(Node):
     """A water utility represented as a set of connections and nodes
@@ -468,7 +528,7 @@ class Pump(Node):
 
     def __repr__(self):
         return (
-            f"<wwtp_configuration.connection.Pump id:{self.id} "
+            f"<wwtp_configuration.node.Pump id:{self.id} "
             f"input_contents:{self.input_contents} "
             f"output_contents:{self.output_contents} "
             f"flow_rate:{self.flow_rate} elevation:{self.elevation} "
